﻿using Mcs.CMOS.DataClient;
using Mcs.CMOS.SpikeView;
using Mcs.CMOS.StreamIO;

namespace CMOS_MEA_Client
{
    public class Control
    {
        private int toolID = 0;
        private int GetNextToolID()
        {
            return toolID++;
        }

        public ClientTool ClientTool { get; private set; }
        public SpikeViewTool SpikeViewTool { get; private set; }

        public Control()
        {
            ClientTool = new ClientTool(GetNextToolID(), "SpikeClientTool");
            ClientTool.EvtState += OnClientToolEvtState;
            ClientTool.EvtSpikeData += OnClientToolEvtSpikeData;
            ClientTool.EvtRemoteEvent += OnClientToolEvtRemoteEvent;

            SpikeViewTool = new SpikeViewTool(GetNextToolID(), "Spike View Tool");
        }

        private void OnClientToolEvtState(ClientTool.StateEventArgs obj)
        {
            if(obj.State == ClientTool.enState.Connected)
            {
                SpikeViewTool.Start();
            }
        }

        public void Close()
        {
            ClientTool.Close();
        }

        private void OnClientToolEvtSpikeData(ClientTool.SpikeDataEventArgs obj)
        {
            SpikeViewTool.SetData(obj.Data);
        }

        private void OnClientToolEvtRemoteEvent(ClientTool.RemoteEventEventArgs obj)
        {
            Event evt = obj.Event;
            if(evt.Source == Mcs.CMOS.StreamIO.Event.enSource.Timer)
            {
                SpikeViewTool.SetCurrentTime(evt.TimeStamp);
            }
            else if (evt.Source == Mcs.CMOS.StreamIO.Event.enSource.Application)
            {
                //public enum enAppState
                //{
                //    ChipOn = 1,
                //    ChipOff = 2,
                //    AcquisitionStart = 3,
                //    AcquisitionStop = 4,
                //    RecorderOff = 5,
                //    RecorderOn = 6,
                //    RecorderArmed = 7
                //}
                if(evt.ID == 3)
                {
                    SpikeViewTool.Start();
                }

            }
            else if (evt.Source == Mcs.CMOS.StreamIO.Event.enSource.Stimulator)
            {
            }
            else if (evt.Source == Mcs.CMOS.StreamIO.Event.enSource.DigitalIn)
            {
            }
        }




    }
}
